@@ -1,5 +1,7 @@
 from topdown._actomizer import Actor
 from topdown._actomizer import Circle
+from topdown._actomizer import Square
+from topdown._actomizer import Triangle
 from topdown._animator import Animation
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
